@@ -39,4 +39,20 @@ clamp(const T1& X, const typename T1::elem_type min_val, const typename T1::elem
 
 
 
+template<typename T1>
+arma_warn_unused
+inline
+const mtOpCube<typename T1::elem_type, T1, op_clamp>
+clamp(const BaseCube<typename T1::elem_type,T1>& X, const typename T1::elem_type min_val, const typename T1::elem_type max_val, typename arma_not_cx<typename T1::elem_type>::result* junk = 0)
+  {
+  arma_extra_debug_sigprint();
+  arma_ignore(junk);
+  
+  arma_debug_check( (min_val > max_val), "clamp(): min_val has to be smaller than max_val" );
+  
+  return mtOpCube<typename T1::elem_type, T1, op_clamp>(mtOpCube_dual_aux_indicator(), X.get_ref(), min_val, max_val);
+  }
+
+
+
 //! @}
